# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['phdi',
 'phdi.cloud',
 'phdi.fhir',
 'phdi.fhir.cloud',
 'phdi.fhir.conversion',
 'phdi.fhir.geospatial',
 'phdi.fhir.harmonization',
 'phdi.fhir.linkage',
 'phdi.fhir.tabulation',
 'phdi.fhir.transport',
 'phdi.geospatial',
 'phdi.harmonization',
 'phdi.linkage',
 'phdi.tabulation',
 'phdi.transport']

package_data = \
{'': ['*']}

install_requires = \
['PyYAML>=6.0,<7.0',
 'azure-identity>=1.10.0,<2.0.0',
 'azure-storage-blob>=12.12.0,<13.0.0',
 'coverage>=6.4.1,<7.0.0',
 'fhirpathpy==0.1.0',
 'google-auth>=2.10.0,<3.0.0',
 'google-cloud-storage>=2.5.0,<3.0.0',
 'hl7>=0.4.5,<0.5.0',
 'pandas>=1.4.2,<2.0.0',
 'phonenumbers>=8.12.48,<9.0.0',
 'polling>=0.3.2,<0.4.0',
 'pyarrow>=8.0.0,<9.0.0',
 'pycountry>=22.3.5,<23.0.0',
 'pydantic>=1.9.0,<2.0.0',
 'smartystreets-python-sdk>=4.10.6,<5.0.0']

setup_kwargs = {
    'name': 'phdi',
    'version': '0.1.0.dev3',
    'description': 'Public health data infrastructure Building Blocks is a library to help public health departments work with their data',
    'long_description': "# PRIME Public Health Data Infrastructure\n[![Test github badge](https://github.com/CDCgov/phdi/actions/workflows/test.yaml/badge.svg)](https://github.com/CDCgov/phdi/actions/workflows/test.yaml)\n[![codecov](https://codecov.io/gh/CDCgov/phdi/branch/main/graph/badge.svg)](https://codecov.io/gh/CDCgov/phdi)\n- [PRIME Public Health Data Infrastructure](#prime-public-health-data-infrastructure)\n  - [Getting Started](#getting-started)\n    - [How to import PHDI](#how-to-import-phdi)\n  - [Overview](#overview)\n    - [Problem Scope](#problem-scope)\n  - [Standard Notices](#standard-notices)\n    - [Public Domain Standard Notice](#public-domain-standard-notice)\n    - [License Standard Notice](#license-standard-notice)\n    - [Privacy Standard Notice](#privacy-standard-notice)\n    - [Contributing Standard Notice](#contributing-standard-notice)\n    - [Records Management Standard Notice](#records-management-standard-notice)\n    - [Related documents](#related-documents)\n    - [Additional Standard Notices](#additional-standard-notices)\n\n**General disclaimer** This repository was created for use by CDC programs to collaborate on public health related projects in support of the [CDC mission](https://www.cdc.gov/about/organization/mission.htm). GitHub is not hosted by the CDC, but is a third party website used by CDC and its partners to share information and collaborate on software. CDC use of GitHub does not imply an endorsement of any one particular service, product, or enterprise.\n\n## Getting Started\n\nIn order to use the PHDI Building Blocks library, you need [Python 3.9 or higher](https://www.python.org/downloads/) and [pip python package manager](https://pip.pypa.io/en/stable/installation/) (or any python package manager)\n\n\nTo install using pip:\n```\npip install phdi\n```\n\n### How to import PHDI\n\nOur project is split up into two parts. Our FHIR supporting version and our generic version.\n\nExample import for FHIR:\n```\n from phdi.fhir.geospatial.census import CensusFhirGeocodeClient\n```\n\nExample import for generic:\n```\n from phdi.geospatial.census import CensusGeocodeClient\n```\n\nEvery building block has a FHIR counterpart that works well with FHIR bundles as inputs. The generic version is used for all other non-FHIR inputs.\n\nFor further information on the tutorial: [Geospatial Tutorial](tutorials/geospatial-tutorial.md)\n\n## Overview\n\nThe PRIME Public Health Data Infrastructure projects are part of the Pandemic-Ready Interoperability Modernization Effort, a multi-year collaboration between CDC and the U.S. Digital Service (USDS) to strengthen data quality and information technology systems in state and local health departments.\n\nThis repository contains source code for a platform to help state, tribal, local and territorial (STLT) public health departments ingest and report on public health data.  It contains the following components:\n\n- **Data Ingestion** - Data ingestion tools provide a common framework to prepare data for storage, and store the data in a common standard data model ([FHIR](https://hl7.org/FHIR/)). \n  - __Harmonization__ - Data harmonization tools can operate on raw input data (HL7 version 2, CCDA) and convert to the common data model format (FHIR).\n  - __Geospatial__ - Geospatial tools provide a common interface for obtaining precise geographic locations based on street addresses from input data.\n  - __Linkage__ - Linkage tools assign a common identifier to patient records to link and deduplicate patients seen across data contributors.\n  - __Transport__ - Transport tools provide a mechanism to store and interact with data stored to a central repostory (FHIR server). \n- **Reporting** - Reporting tools define a dynamic framework for building custom data models in an analysis-ready output format.\n  - __Tabluation__ - Tabulation provides tools to retrieve data dynamically-defined records and data fields from the common data platform (FHIR server), extract, convert it to a tabular representation, and store to a user-defined tabular storage file type (Parquet or CSV).\n- **Implementation Support** - Implemetnation resources support implementing STLTs to configure a PHDI-driven workflow to manage their data and analysis workflows.\n  - __Cloud-agnostic tools__ - A common PHDI programming interface supports STLTs interacting with cloud-based data storage (containers/buckets), and FHIR servers in a common way.\n  - __Examples and Tutorials__ - Example and tutorial materials help STLTs implement the PHDI solution more quickly by providing easy-to-follow examples and tutorials.\n\nThe PRIME Public Health Data Infrastructure prototype a sibling project to [PRIME ReportStream](https://reportstream.cdc.gov), focusing on delivering COVID-19 test data to public health departments, and [PRIME SimpleReport](https://simplereport.gov), working on a better way to report COVID-19 rapid tests.\n\n### Problem Scope\n\nLong-term Vision: Current public health systems to digest, analyze, and respond to data are siloed. Lacking access to actionable data, our national, as well as state, local, and territorial infrastructure, isn’t pandemic-ready. Our objective is to help the CDC best support STLTs in moving towards a modern public health data infrastructure.\n\n## Standard Notices\n\n### Public Domain Standard Notice\n\nThis repository constitutes a work of the United States Government and is not\nsubject to domestic copyright protection under 17 USC § 105. This repository is in\nthe public domain within the United States, and copyright and related rights in\nthe work worldwide are waived through the [CC0 1.0 Universal public domain dedication](https://creativecommons.org/publicdomain/zero/1.0/).\nAll contributions to this repository will be released under the CC0 dedication. By\nsubmitting a pull request you are agreeing to comply with this waiver of\ncopyright interest.\n\n### License Standard Notice\n\nThis project is in the public domain within the United States, and copyright and\nrelated rights in the work worldwide are waived through the [CC0 1.0 Universal public domain dedication](https://creativecommons.org/publicdomain/zero/1.0/).\nAll contributions to this project will be released under the CC0 dedication. By\nsubmitting a pull request or issue, you are agreeing to comply with this waiver\nof copyright interest and acknowledge that you have no expectation of payment,\nunless pursuant to an existing contract or agreement.\n\n### Privacy Standard Notice\n\nThis repository contains only non-sensitive, publicly available data and\ninformation. All material and community participation is covered by the\n[Disclaimer](https://github.com/CDCgov/template/blob/master/DISCLAIMER.md)\nand [Code of Conduct](https://github.com/CDCgov/template/blob/master/code-of-conduct.md).\nFor more information about CDC's privacy policy, please visit [http://www.cdc.gov/other/privacy.html](https://www.cdc.gov/other/privacy.html).\n\n### Contributing Standard Notice\n\nAnyone is encouraged to contribute to the repository by [forking](https://help.github.com/articles/fork-a-repo)\nand submitting a pull request. (If you are new to GitHub, you might start with a\n[basic tutorial](https://help.github.com/articles/set-up-git).) By contributing\nto this project, you grant a world-wide, royalty-free, perpetual, irrevocable,\nnon-exclusive, transferable license to all users under the terms of the\n[Apache Software License v2](http://www.apache.org/licenses/LICENSE-2.0.html) or\nlater.\n\nAll comments, messages, pull requests, and other submissions received through\nCDC including this GitHub page may be subject to applicable federal law, including but not limited to the Federal Records Act, and may be archived. Learn more at [http://www.cdc.gov/other/privacy.html](http://www.cdc.gov/other/privacy.html).\n\nSee [CONTRIBUTING.md](docs/CONTRIBUTING.md) for more information.\n\n### Records Management Standard Notice\n\nThis repository is not a source of government records, but is a copy to increase\ncollaboration and collaborative potential. All government records will be\npublished through the [CDC web site](http://www.cdc.gov).\n\n### Related documents\n\n- [Open Practices](docs/open_practices.md)\n- [Rules of Behavior](docs/rules_of_behavior.md)\n- [Disclaimer](docs/DISCLAIMER.md)\n- [Contribution Notice](docs/CONTRIBUTING.md)\n- [Code of Conduct](docs/code-of-conduct.md)\n\n### Additional Standard Notices\n\nPlease refer to [CDC's Template Repository](https://github.com/CDCgov/template)\nfor more information about [contributing to this repository](https://github.com/CDCgov/template/blob/master/CONTRIBUTING.md),\n[public domain notices and disclaimers](https://github.com/CDCgov/template/blob/master/DISCLAIMER.md),\nand [code of conduct](https://github.com/CDCgov/template/blob/master/code-of-conduct.md).\n",
    'author': 'Kenneth Chow',
    'author_email': 'kenneth@skylight.digital',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/CDCgov/phdi',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
